@@ -4,10 +4,9 @@ import json
 import logging
 
 from bson import json_util
-from flask import Blueprint, current_app, jsonify, request
+from flask import Blueprint, current_app, jsonify, render_template, request
 from flask_negotiate import consumes, produces
 from patientMatcher.auth.auth import authorize
-from patientMatcher.constants import STATUS_CODES
 from patientMatcher.match.handler import async_match, internal_matcher, patient_matches
 from patientMatcher.utils.add import backend_add_patient
 from patientMatcher.utils.notify import notify_match_external, notify_match_internal
@@ -19,6 +18,13 @@ blueprint = Blueprint("server", __name__)
 API_MIME_TYPE = "application/vnd.ga4gh.matchmaker.v1.0+json"
 
 
+@blueprint.route("/", methods=["GET"])
+def index():
+    """Provide an index page with general node description and stats"""
+    data = controllers.populate_index_data()
+    return render_template("index.html", **data)
+
+
 @blueprint.route("/patient/add", methods=["POST"])
 @consumes(API_MIME_TYPE, "application/json")
 @produces("application/json")
@@ -99,7 +105,7 @@ def heartbeat():
 def metrics():
     """Get database metrics"""
     LOG.info("Receiving a requests for server metrics.")
-    results = controllers.metrics(database=current_app.db)
+    results = controllers.metrics()
     resp = jsonify({"metrics": results, "disclaimer": current_app.config.get("DISCLAIMER")})
     resp.status_code = 200
     return resp
@@ -278,8 +284,7 @@ def match_internal():
         current_app.db, query_patient, max_pheno_score, max_geno_score, max_results, score_threshold
     )
     # save matching object to database
-    if match_obj and (match_obj.get("has_matches") or match_obj.get("errors")):
-        current_app.db["matches"].insert_one(match_obj)
+    current_app.db["matches"].insert_one(match_obj)
     matches = []
     try:
         matches = match_obj["results"][0][
